<?php

namespace B2buy\Scheduler\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Scheduler\Models\Scheduler;

class SchedulerPolicy
{

    /**
     * Determine if the given user can view the scheduler.
     *
     * @param UserPolicy $user
     * @param Scheduler $scheduler
     *
     * @return bool
     */
    public function view(UserPolicy $user, Scheduler $scheduler)
    {
        if ($user->canDo('scheduler.scheduler.view') && $user->isAdmin()) {
            return true;
        }

        return $scheduler->user_id == user_id() && $scheduler->user_type == user_type();
    }

    /**
     * Determine if the given user can create a scheduler.
     *
     * @param UserPolicy $user
     * @param Scheduler $scheduler
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('scheduler.scheduler.create');
    }

    /**
     * Determine if the given user can update the given scheduler.
     *
     * @param UserPolicy $user
     * @param Scheduler $scheduler
     *
     * @return bool
     */
    public function update(UserPolicy $user, Scheduler $scheduler)
    {
        if ($user->canDo('scheduler.scheduler.edit') && $user->isAdmin()) {
            return true;
        }

        return $scheduler->user_id == user_id() && $scheduler->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given scheduler.
     *
     * @param UserPolicy $user
     * @param Scheduler $scheduler
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Scheduler $scheduler)
    {
        return $scheduler->user_id == user_id() && $scheduler->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given scheduler.
     *
     * @param UserPolicy $user
     * @param Scheduler $scheduler
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Scheduler $scheduler)
    {
        if ($user->canDo('scheduler.scheduler.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given scheduler.
     *
     * @param UserPolicy $user
     * @param Scheduler $scheduler
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Scheduler $scheduler)
    {
        if ($user->canDo('scheduler.scheduler.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
